@@ -15,7 +15,7 @@
 # limitations under the License.
 
 readonly ROOT_DIR=$(dirname $0)/..
-source ${ROOT_DIR}/vendor/github.com/knative/test-infra/scripts/library.sh
+source ${ROOT_DIR}/vendor/knative.dev/test-infra/scripts/library.sh
 
 set -o errexit
 set -o nounset
@@ -26,12 +26,19 @@ cd ${ROOT_DIR}
 # Ensure we have everything we need under vendor/
 dep ensure
 
-# The license for this is embedded in the readme.
-sed -n '11,41p' vendor/bitbucket.org/ww/goautoneg/README.txt > vendor/bitbucket.org/ww/goautoneg/LICENSE
-
 rm -rf $(find vendor/ -name 'OWNERS')
 rm -rf $(find vendor/ -name '*_test.go')
-rm -rf vendor/github.com/knative/test-infra/devstats
 
 update_licenses third_party/VENDOR-LICENSE "./cmd/*"
+
+# Patch k8s.io/client-go/tools/cache and k8s.io/kbernetes/pkg/credentialprovider
+# to make k8schain work with ECR. This is a workaround for:
+# https://github.com/google/go-containerregistry/issues/355
+#
+# Once we're on 1.15 we can drop this patch, but we will have to be careful when
+# bumping kubernetes dependencies.
+#
+# TODO(#4549): Drop this patch.
+git apply ${REPO_ROOT_DIR}/hack/1996.patch
+
 remove_broken_symlinks ./vendor
