@@ -101,22 +101,32 @@ var gatewayWithPlaceholderServer = v1alpha3.Gateway{
 	},
 }
 
+var ingressSpec = v1alpha1.IngressSpec{
+	Rules: []v1alpha1.IngressRule{{
+		Hosts: []string{"host1.example.com"},
+	}},
+	TLS: []v1alpha1.IngressTLS{{
+		Hosts:             []string{"host1.example.com"},
+		SecretName:        "secret0",
+		SecretNamespace:   system.Namespace(),
+		ServerCertificate: "tls.crt",
+		PrivateKey:        "tls.key",
+	}},
+}
+
 var clusterIngress = v1alpha1.ClusterIngress{
 	ObjectMeta: metav1.ObjectMeta{
 		Name: "clusteringress",
 	},
-	Spec: v1alpha1.IngressSpec{
-		Rules: []v1alpha1.IngressRule{{
-			Hosts: []string{"host1.example.com"},
-		}},
-		TLS: []v1alpha1.IngressTLS{{
-			Hosts:             []string{"host1.example.com"},
-			SecretName:        "secret0",
-			SecretNamespace:   system.Namespace(),
-			ServerCertificate: "tls.crt",
-			PrivateKey:        "tls.key",
-		}},
+	Spec: ingressSpec,
+}
+
+var ingress = v1alpha1.Ingress{
+	ObjectMeta: metav1.ObjectMeta{
+		Name:      "ingress",
+		Namespace: "default",
 	},
+	Spec: ingressSpec,
 }
 
 func TestGetServers(t *testing.T) {
@@ -160,7 +170,7 @@ func TestGetHTTPServer(t *testing.T) {
 func TestMakeTLSServers(t *testing.T) {
 	cases := []struct {
 		name                    string
-		ci                      *v1alpha1.ClusterIngress
+		ci                      v1alpha1.IngressAccessor
 		gatewayServiceNamespace string
 		originSecrets           map[string]*corev1.Secret
 		expected                []v1alpha3.Server
@@ -205,6 +215,26 @@ func TestMakeTLSServers(t *testing.T) {
 				CredentialName:    "secret0",
 			},
 		}},
+	}, {
+		name:                    "port name is created with ingress namespace-name",
+		ci:                      &ingress,
+		gatewayServiceNamespace: system.Namespace(),
+		originSecrets:           originSecrets,
+		expected: []v1alpha3.Server{{
+			Hosts: []string{"host1.example.com"},
+			Port: v1alpha3.Port{
+				// port name is created with <namespace>/<name>
+				Name:     "default/ingress:0",
+				Number:   443,
+				Protocol: v1alpha3.ProtocolHTTPS,
+			},
+			TLS: &v1alpha3.TLSOptions{
+				Mode:              v1alpha3.TLSModeSimple,
+				ServerCertificate: "tls.crt",
+				PrivateKey:        "tls.key",
+				CredentialName:    "secret0",
+			},
+		}},
 	}, {
 		name:                    "error to make servers because of incorrect originSecrets",
 		ci:                      &clusterIngress,
@@ -600,7 +630,7 @@ func serviceLister(svcs ...*corev1.Service) corev1listers.ServiceLister {
 	services := informer.Core().V1().Services()
 
 	for _, svc := range svcs {
-		fake.Core().Services(svc.Namespace).Create(svc)
+		fake.CoreV1().Services(svc.Namespace).Create(svc)
 		services.Informer().GetIndexer().Add(svc)
 	}
 
@@ -630,7 +660,7 @@ func TestGatewayName(t *testing.T) {
 
 func TestCanProbeGateway(t *testing.T) {
 	cases := []struct {
-		name string
+		name     string
 		gateway  *v1alpha3.Gateway
 		canProbe bool
 	}{{
@@ -639,65 +669,65 @@ func TestCanProbeGateway(t *testing.T) {
 			Spec: v1alpha3.GatewaySpec{
 				Servers: []v1alpha3.Server{{
 					Hosts: []string{"*"},
-					Port:v1alpha3.Port{
-						Number: 80,
+					Port: v1alpha3.Port{
+						Number:   80,
 						Protocol: v1alpha3.ProtocolHTTP,
 					},
 				}},
 			},
 		},
 		canProbe: true,
-	},{
+	}, {
 		name: "specific host HTTP on port 80",
 		gateway: &v1alpha3.Gateway{
 			Spec: v1alpha3.GatewaySpec{
 				Servers: []v1alpha3.Server{{
 					Hosts: []string{"foo.bar.com"},
-					Port:v1alpha3.Port{
-						Number: 100,
+					Port: v1alpha3.Port{
+						Number:   100,
 						Protocol: v1alpha3.ProtocolHTTP,
 					},
 				}},
 			},
 		},
 		canProbe: false,
-	},{
+	}, {
 		name: "wildcard HTTP on port !80",
 		gateway: &v1alpha3.Gateway{
 			Spec: v1alpha3.GatewaySpec{
 				Servers: []v1alpha3.Server{{
 					Hosts: []string{"*"},
-					Port:v1alpha3.Port{
-						Number: 100,
+					Port: v1alpha3.Port{
+						Number:   100,
 						Protocol: v1alpha3.ProtocolHTTP,
 					},
 				}},
 			},
 		},
-		canProbe: false,
-	},{
+		canProbe: true,
+	}, {
 		name: "wildcard TCP on port 80",
 		gateway: &v1alpha3.Gateway{
 			Spec: v1alpha3.GatewaySpec{
 				Servers: []v1alpha3.Server{{
 					Hosts: []string{"*"},
-					Port:v1alpha3.Port{
-						Number: 80,
+					Port: v1alpha3.Port{
+						Number:   80,
 						Protocol: v1alpha3.ProtocolTCP,
 					},
 				}},
 			},
 		},
 		canProbe: false,
-	},{
+	}, {
 		name: "wildcard HTTPS on port 443",
 		gateway: &v1alpha3.Gateway{
 			Spec: v1alpha3.GatewaySpec{
 				Servers: []v1alpha3.Server{{
 					Hosts: []string{"*"},
-					Port:v1alpha3.Port{
-						Number: 100,
-						Protocol: v1alpha3.ProtocolHTTP,
+					Port: v1alpha3.Port{
+						Number:   100,
+						Protocol: v1alpha3.ProtocolHTTPS,
 					},
 				}},
 			},
